==> kdevelop-4.6.90.tar.xz: kdevelop-4.6.90/kdeintegration/executeplasmoid/kdevexecuteplasmoid.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Lets you view a plasmoid
Comment[bs]=Omogućava da vidite plazmoid
Comment[ca]=Us permet veure un plasmoide
Comment[ca@valencia]=Vos permet veure un plasmoide
Comment[da]=Lader dig se en plasmoid
Comment[de]=Zeigt ein Plasmoid an
Comment[el]=Σας επιτρέπει να δείτε ένα πλασμοειδές
Comment[es]=Le deja ver un plasmoide
Comment[et]=Võimaldab näha plasmoidi
Comment[fi]=Mahdollistaa plasmoidin katselun
Comment[fr]=Permet d'afficher un composant graphique
Comment[gl]=Permite ver un plasmoide
Comment[hu]=Lehetővé teszi egy plasmoid megtekintését
Comment[it]=Consente di visualizzare un plasmoide
Comment[kk]=Плазмоид жұмысын қарау
Comment[nb]=Lar deg se en plasmoide
Comment[nl]=Laat u een plasmoid bekijken
Comment[pl]=Pozwala tobie na obejrzenie plazmoidu
Comment[pt]=Permite-lhe visualizar um plasmóide
Comment[pt_BR]=Permite-lhe visualizar um plasmoide
Comment[ru]=Позволяет испытать плазмоид
Comment[sk]=Umožní vám vidieť plazmoid
Comment[sl]=Vam omogoča ogled plasmoida
Comment[sv]=Låter dig visa en Plasmoid
Comment[uk]=Надає вам змогу переглядати роботу плазмоїдів
Comment[x-test]=xxLets you view a plasmoidxx
Comment[zh_CN]=让您查看一个 plasmoid
Comment[zh_TW]=讓您檢視一個 plasmoid 元件
Name=Plasmoid Launcher
Name[bs]=Pokretač plazmoida
Name[ca]=Llançador de plasmoide
Name[ca@valencia]=Llançador de plasmoide
Name[da]=Plasmoidstarter
Name[de]=Plasmoid-Starter
Name[el]=Εκτελεστής πλασμοειδών
Name[es]=Lanzador de plasmoide
Name[et]=Plasmoidi käivitaja
Name[fi]=Plasmoidikäynnistin
Name[fr]=Lanceur de composant graphique
Name[gl]=Iniciador de plasmoides
Name[hu]=Plasmoid indító
Name[it]=Lanciatore di plasmoidi
Name[kk]=Плазмоид жеккіші
Name[nb]=Plasmoidestarter
Name[nds]=Oproper för Plasma-Lüttprogrammen
Name[nl]=Programmastarter van plasmoid
Name[pl]=Program uruchamiający plazmoid
Name[pt]=Lançamento de Plasmóides
Name[pt_BR]=Lançador de plasmoides
Name[ru]=Запуск плазмоида
Name[sk]=Spúšťač plazmoidov
Name[sl]=Zaganjalnik Plasmoidov
Name[sv]= Plasmoid-startprogram
Name[uk]=Засіб запуску плазмоїдів
Name[x-test]=xxPlasmoid Launcherxx
Name[zh_CN]=Plasmoid 启动器
Name[zh_TW]=Plasmoid 啟動器
GenericName=Plasmoid Launcher Support
GenericName[bs]=Podrška za pokretač plazmoida
GenericName[ca]=Implementació de llançadors de plasmoides
GenericName[ca@valencia]=Implementació de llançadors de plasmoides
GenericName[da]=Understøttelse af plasmoidstarteren
GenericName[de]=Unterstützung für Plasmoid-Starter
GenericName[el]=Υποστήριξη εκτελεστή πλασμοειδών
GenericName[es]=Implementación de lanzador de plasmoide
GenericName[et]=Plasmodi käivitaja toetus
GenericName[fi]=Plasmoidikäynnistintuki
GenericName[fr]=Prise en charge du lanceur de composants graphiques
GenericName[gl]=Axuda do iniciador de plasmoides
GenericName[hu]=Plasmoid indító támogatás
GenericName[it]=Supporto al lanciatore di plasmoidi
GenericName[kk]=Плазмоид жеккішін қолдау
GenericName[nb]=Plasmoid startstøtte
GenericName[nl]=Ondersteuning van programmastarter van plasmoid
GenericName[pl]=Obsługa programu uruchamiającego plazmoid
GenericName[pt]=Suporte para o Lançamento de Plasmóides
GenericName[pt_BR]=Suporte ao lançador de plasmoides
GenericName[ru]=Поддержка запуска плазмоида
GenericName[sk]=Podpora spúšťača plazmoidov
GenericName[sl]=Podpora zaganjalniku Plasmoidov
GenericName[sv]=Stöd för Plasmoid-startprogram
GenericName[uk]=Підтримка засобу запуску плазмоїдів
GenericName[x-test]=xxPlasmoid Launcher Supportxx
GenericName[zh_CN]=Plasmoid 启动器支持
GenericName[zh_TW]=Plasmoid 啟動器支援
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevexecuteplasmoid
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevexecuteplasmoid
X-KDE-PluginInfo-Author=Aleix Pol Gonzalez
X-KDE-PluginInfo-License=GPL
X-KDevelop-Interfaces=org.kdevelop.IExecutePlugin
X-KDevelop-Mode=NoGUI

==> kdevelop-4.7.0.tar.xz: kdevelop-4.7.0/kdeintegration/executeplasmoid/kdevexecuteplasmoid.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=system-run
Exec=blubb
Comment=Lets you view a plasmoid
Comment[bs]=Omogućava da vidite plazmoid
Comment[ca]=Us permet veure un plasmoide
Comment[ca@valencia]=Vos permet veure un plasmoide
Comment[da]=Lader dig vise en plasmoid
Comment[de]=Zeigt ein Plasmoid an
Comment[el]=Σας επιτρέπει να δείτε ένα πλασμοειδές
Comment[en_GB]=Lets you view a plasmoid
Comment[es]=Le deja ver un plasmoide
Comment[et]=Võimaldab näha plasmoidi
Comment[fi]=Mahdollistaa plasmoidin katselun
Comment[fr]=Permet d'afficher un composant graphique
Comment[gl]=Permite ver un plasmoide
Comment[hu]=Lehetővé teszi egy plasmoid megtekintését
Comment[it]=Consente di visualizzare un plasmoide
Comment[kk]=Плазмоид жұмысын қарау
Comment[nb]=Lar deg se en plasmoide
Comment[nl]=Laat u een plasmoid bekijken
Comment[pl]=Pozwala tobie na obejrzenie plazmoidu
Comment[pt]=Permite-lhe visualizar um plasmóide
Comment[pt_BR]=Permite-lhe visualizar um plasmoide
Comment[ru]=Позволяет испытать плазмоид
Comment[sk]=Umožní vám vidieť plazmoid
Comment[sl]=Vam omogoča ogled plasmoida
Comment[sv]=Låter dig visa en Plasmoid
Comment[uk]=Надає вам змогу переглядати роботу плазмоїдів
Comment[x-test]=xxLets you view a plasmoidxx
Comment[zh_CN]=让您查看一个 plasmoid
Comment[zh_TW]=讓您檢視一個 plasmoid 元件
Name=Plasmoid Launcher
Name[bs]=Pokretač plazmoida
Name[ca]=Llançador de plasmoide
Name[ca@valencia]=Llançador de plasmoide
Name[da]=Plasmoid-starter
Name[de]=Plasmoid-Starter
Name[el]=Εκτελεστής πλασμοειδών
Name[en_GB]=Plasmoid Launcher
Name[es]=Lanzador de plasmoide
Name[et]=Plasmoidi käivitaja
Name[fi]=Plasmoidikäynnistin
Name[fr]=Lanceur de composant graphique
Name[gl]=Iniciador de plasmoides
Name[hu]=Plasmoid indító
Name[it]=Lanciatore di plasmoidi
Name[kk]=Плазмоид жеккіші
Name[nb]=Plasmoidestarter
Name[nds]=Oproper för Plasma-Lüttprogrammen
Name[nl]=Programmastarter van plasmoid
Name[pl]=Program uruchamiający plazmoid
Name[pt]=Lançamento de Plasmóides
Name[pt_BR]=Lançador de plasmoides
Name[ru]=Запуск плазмоида
Name[sk]=Spúšťač plazmoidov
Name[sl]=Zaganjalnik Plasmoidov
Name[sv]= Plasmoid-startprogram
Name[uk]=Засіб запуску плазмоїдів
Name[x-test]=xxPlasmoid Launcherxx
Name[zh_CN]=Plasmoid 启动器
Name[zh_TW]=Plasmoid 啟動器
GenericName=Plasmoid Launcher Support
GenericName[bs]=Podrška za pokretač plazmoida
GenericName[ca]=Implementació de llançadors de plasmoides
GenericName[ca@valencia]=Implementació de llançadors de plasmoides
GenericName[da]=Understøttelse af Plasmoid-starter
GenericName[de]=Unterstützung für Plasmoid-Starter
GenericName[el]=Υποστήριξη εκτελεστή πλασμοειδών
GenericName[en_GB]=Plasmoid Launcher Support
GenericName[es]=Implementación de lanzador de plasmoide
GenericName[et]=Plasmodi käivitaja toetus
GenericName[fi]=Plasmoidikäynnistintuki
GenericName[fr]=Prise en charge du lanceur de composants graphiques
GenericName[gl]=Axuda do iniciador de plasmoides
GenericName[hu]=Plasmoid indító támogatás
GenericName[it]=Supporto al lanciatore di plasmoidi
GenericName[kk]=Плазмоид жеккішін қолдау
GenericName[nb]=Plasmoid startstøtte
GenericName[nl]=Ondersteuning van programmastarter van plasmoid
GenericName[pl]=Obsługa programu uruchamiającego plazmoid
GenericName[pt]=Suporte para o Lançamento de Plasmóides
GenericName[pt_BR]=Suporte ao lançador de plasmoides
GenericName[ru]=Поддержка запуска плазмоида
GenericName[sk]=Podpora spúšťača plazmoidov
GenericName[sl]=Podpora zaganjalniku Plasmoidov
GenericName[sv]=Stöd för Plasmoid-startprogram
GenericName[uk]=Підтримка засобу запуску плазмоїдів
GenericName[x-test]=xxPlasmoid Launcher Supportxx
GenericName[zh_CN]=Plasmoid 启动器支持
GenericName[zh_TW]=Plasmoid 啟動器支援
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevexecuteplasmoid
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevexecuteplasmoid
X-KDE-PluginInfo-Author=Aleix Pol Gonzalez
X-KDE-PluginInfo-License=GPL
X-KDevelop-Interfaces=org.kdevelop.IExecutePlugin
X-KDevelop-Mode=NoGUI
